The alleleCount program primarily exists to prevent code duplication
between some other projects, specifically AscatNGS and Battenberg.
Usage
allele_counter(
hts_file,
loci_file,
ofile,
...,
odir = getwd(),
alleleCounter = NULL
)Arguments
- hts_file
A string of path to sample HTS file.
- loci_file
A string of path to loci file.
- ofile
A string of path to the output file.
- ...
<dynamic dots> Additional arguments passed to
alleleCountercommand. Empty arguments are automatically trimmed. If a single argument, such as a file path, contains spaces, it must be quoted, for example usingshQuote(). Details see:cmd_help(alleleCounter()).- odir
A string of path to the output directory.
- alleleCounter
A string of path to
alleleCountercommand.
See also
Other commands:
bcftools(),
bedtools(),
bowtie2(),
bwa(),
cellranger(),
conda(),
fastp(),
fastq_pair(),
freebayes(),
gistic2(),
kraken2(),
kraken_tools(),
minimap2(),
perl(),
pyscenic(),
python(),
samtools(),
seqkit(),
snpEff(),
strelka(),
trust4(),
varscan()