Skip to contents

freebayes is a Bayesian genetic variant detector designed to find small polymorphisms, specifically SNPs (single-nucleotide polymorphisms), indels (insertions and deletions), MNPs (multi-nucleotide polymorphisms), and complex events (composite insertion and substitution events) smaller than the length of a short-read sequencing alignment.

Usage

freebayes(ref, input, ofile, ..., freebayes = NULL)

Arguments

ref

A string of reference file path.

input

A string of path to the input bam file.

ofile

A string of path to the output vcf file.

...

<dynamic dots> Additional arguments passed to freebayes command. Empty arguments are automatically trimmed. If a single argument, such as a file path, contains spaces, it must be quoted, for example using shQuote(). Details see: cmd_help(freebayes()).

freebayes

A string of path to freebayes command.

Value

A command object.