Skip to contents

Minimap2 is a versatile sequence alignment program that aligns DNA or mRNA sequences against a large reference database. Typical use cases include: (1) mapping PacBio or Oxford Nanopore genomic reads to the human genome; (2) finding overlaps between long reads with error rate up to ~15%; (3) splice-aware alignment of PacBio Iso-Seq or Nanopore cDNA or Direct RNA reads against a reference genome; (4) aligning Illumina single- or paired-end reads; (5) assembly-to-assembly alignment; (6) full-genome alignment between two closely related species with divergence below ~15%.

Usage

minimap2(method, ref, reads, ofile, ..., minimap2 = NULL)

Arguments

method

Mapping preset: "map-ont" (single-end long reads) or "sr" (paired-end short reads).

ref

Path to the reference genome FASTA file.

reads

A character vector of FASTQ files used as input to minimap2.

ofile

A string of path to the output SAM file.

...

<dynamic dots> Additional arguments passed to minimap2 command. Empty arguments are automatically trimmed. If a single argument, such as a file path, contains spaces, it must be quoted, for example using shQuote(). Details see: cmd_help(minimap2()).

minimap2

A string of path to minimap2 command.

Value

A command object.