Skip to contents

Strelka is a fast and accurate small variant caller optimized for analysis of germline variation in small cohorts and somatic variation in tumor/normal sample pairs.

Usage

strelka(script, ...)

Arguments

script

Name of the Strelka script. One of "configureStrelkaGermlineWorkflow", "configureStrelkaSomaticWorkflow", and "runWorkflow".

...

<dynamic dots> Additional arguments passed to strelka command. Empty arguments are automatically trimmed. If a single argument, such as a file path, contains spaces, it must be quoted, for example using shQuote(). Details see: cmd_help(strelka()).

strelka

A string of path to strelka command.

Value

A command object.