freebayes is a Bayesian genetic variant detector designed to find small polymorphisms, specifically SNPs (single-nucleotide polymorphisms), indels (insertions and deletions), MNPs (multi-nucleotide polymorphisms), and complex events (composite insertion and substitution events) smaller than the length of a short-read sequencing alignment.
Arguments
- ref
A string of reference file path.
- input
A string of path to the input bam file.
- ofile
A string of path to the output vcf file.
- ...
<dynamic dots> Additional arguments passed to
freebayescommand. Empty arguments are automatically trimmed. If a single argument, such as a file path, contains spaces, it must be quoted, for example usingshQuote(). Details see:cmd_help(freebayes()).- freebayes
A string of path to
freebayescommand.
See also
Other commands:
allele_counter(),
bcftools(),
bedtools(),
bowtie2(),
bwa(),
cellranger(),
conda(),
fastp(),
fastq_pair(),
gistic2(),
kraken2(),
kraken_tools(),
minimap2(),
perl(),
pyscenic(),
python(),
samtools(),
seqkit(),
snpEff(),
strelka(),
trust4(),
varscan()