Strelka is a fast and accurate small variant caller optimized for analysis of germline variation in small cohorts and somatic variation in tumor/normal sample pairs.
Arguments
- script
Name of the Strelka script. One of
"configureStrelkaGermlineWorkflow","configureStrelkaSomaticWorkflow", and"runWorkflow".- ...
<dynamic dots> Additional arguments passed to
strelkacommand. Empty arguments are automatically trimmed. If a single argument, such as a file path, contains spaces, it must be quoted, for example usingshQuote(). Details see:cmd_help(strelka()).- strelka
A string of path to
strelkacommand.
See also
Other commands:
allele_counter(),
bcftools(),
bedtools(),
bowtie2(),
bwa(),
cellranger(),
conda(),
fastp(),
fastq_pair(),
freebayes(),
gistic2(),
kraken2(),
kraken_tools(),
minimap2(),
perl(),
pyscenic(),
python(),
samtools(),
seqkit(),
snpEff(),
trust4(),
varscan()